use strict;

use vars qw($VERSION %IRSSI);
$VERSION = "20140521";
%IRSSI = (
    authors     => "Someone",
    contact     => "someone\@somenet.org",
    name        => "bitlbee log + otr disconnect",
    description => "invisibly logs join, part, quit, modes and closes otr sessions",
    license     => "GPLv2",
    changed     => "$VERSION",
);

use Irssi;

sub event_join () {
    my ($server, $channel, $nick, $address) = @_;
	return if not ($server->{tag} =~ /bitlbee/);
	Irssi::signal_stop() if ($server->{tag} =~ /bitlbee/);
	for my $log (Irssi::logs()){
	  for my $li ($log->{items}[0]){
	    if ($li->{servertag}.$li->{name} eq $server->{tag}.$channel){
		  $log->write_rec('-!- '.$nick.' ['.$address.'] has joined '.$channel, 1337);
		}
	  }
	}
}

sub event_quit () {
    my ($server, $nick, $address, $msg) = @_;
	return if not ($server->{tag} =~ /bitlbee/);
	Irssi::signal_stop() if ($server->{tag} =~ /bitlbee/);
	for my $log (Irssi::logs()){
	  for my $li ($log->{items}[0]){
	    if ($li->{servertag} eq $server->{tag} and ($li->{name} eq '&bitlbee' or $li->{name} eq $nick)){
		  $log->write_rec('-!- '.$nick.' ['.$address.'] has quit ['.$msg.']', 1337);
		}
	  }
	}
	my $break = 1;
	for my $win (Irssi::queries()) {
		$break = 0 if ($win->{'visible_name'} eq $nick);
	}
	return if ($break == 1);
	$server->command("MSG &bitlbee otr disconnect ".$nick);
}

sub event_part () {
    my ($server, $channel, $nick, $address, $msg) = @_;
	return if not ($server->{tag} =~ /bitlbee/);
	Irssi::signal_stop() if ($server->{tag} =~ /bitlbee/);
	for my $log (Irssi::logs()){
	  for my $li ($log->{items}[0]){
	    if ($li->{servertag}.$li->{name} eq $server->{tag}.$channel){
		  $log->write_rec('-!- '.$nick.' ['.$address.'] has left '.$channel.' ['.$msg.']', 1337);
		}
	  }
	}
}

sub event_mode () {
    my ($server, $channel, $nick, $address, $mode) = @_;
	return if not ($server->{tag} =~ /bitlbee/);
	Irssi::signal_stop() if ($server->{tag} =~ /bitlbee/);
	for my $log (Irssi::logs()){
	  for my $li ($log->{items}[0]){
	    if ($li->{servertag}.$li->{name} eq $server->{tag}.$channel){
		  $log->write_rec('-!- ServerMode/'.$channel.' ['.$mode.'] by '.$nick, 1337);
		}
	  }
	}
}

sub cmd_wc () {
	my ($data, $server, $witem) = @_;
	if ($witem && ($witem->{type} eq "QUERY")) {
		$server->command("MSG &bitlbee otr disconnect ".$witem->{'visible_name'}) if ($server->{tag} =~ /bitlbee/);
	}
	Irssi::command("window close");
}

Irssi::signal_add('message join', \&event_join);
Irssi::signal_add('message quit', \&event_quit);
Irssi::signal_add('message part', \&event_part);
Irssi::signal_add('message irc mode', \&event_mode);
Irssi::command_bind('wc', 'cmd_wc');
